@@ -42,3 +42,7 @@
   # Return error status
   return(hasError)
 }
+
+.setMaxGlobalSize <- function(maxSize) {
+  options(future.globals.maxSize= maxSize*1024^2)
+}
